<template>
    <table class="table">
        <thead class="table__head">
            <tr class="table__head-row">
                <td class="table__head-item">
                    Пользователь
                </td>
                <td class="table__head-item">
                    Дата разблокировки (МСК)
                </td>
                <td class="table__head-item">
                    Причина
                </td>
                <td class="table__head-item">
                    Действие
                </td>
            </tr>
        </thead>
        <tbody class="table__body">
            <tr class="table__body-row" v-for="user in users">
                <td class="table__body-item table__padding" style="display: flex; align-items: center;">
                    <img :src="user.photo_200" style="width: 32px; border-radius: 4px; margin-right: 10px;" />
                    <span 
                        @click="$root.$emit('showProfile', user.id)" 
                        style="cursor: pointer"
                    >
                        {{ user.username }}
                    </span>
                </td>
                <td class="table__body-item">
                    {{ fromUnix(user.chat_ban) }}
                </td>
                <td class="table__body-item">
                    {{ user.chat_ban_reason }}
                </td>
                <td class="table__body-item">
                    <span style="cursor: pointer;" @click="unmute(user.id)">Разблокировать</span>
                </td>
            </tr>
        </tbody>
    </table>
</template>


<script>
export default {
    data() {
        return {
            users: [],
        }
    },
    mounted() {
        this.init();
    },
    methods: {
        init() {
            this.$root.axios.post('/message/banlist')
            .then(response => {
                const {data} = response
                this.users = data
            })
        },
        unmute(user_id) {
            this.users = this.users.filter(user => user.id !== user_id)
            this.$root.axios.post('/message/unmute', {
                user_id
            })
            .then(response => {
                const {data} = response

                if(data.length == 0) {
                    return this.$router.push({name: index})
                }

                if(data.error) {
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                notify({
                    theme: 'green',
                    text: data.text
                })
            })
        },
        formatUnix(unix_timestamp) {
            return new Date(unix_timestamp * 1000 + 3600000 * 3)
                .toISOString()
                .slice(0, 19)
                .replace('T', ' ')
        },
        fromUnix(unix) {
            var time = this.formatUnix(unix)
            var part = time.split(' ')

            var normal = part[0].split('-');

            return `${part[1]} ${normal[2]}.${normal[1]}.${normal[0]}`
        }
    },
    sockets: {
        'delete.message': function(data) {
            if(data.type == 'ban') {
                this.init()
            }
        }
    }
}
</script>

<style scoped>
.table {
    margin: 0!important
}
</style>